==> haskell-generic-deriving-1.12.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-generic-deriving.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-deriving
version: 1.12.1
id: generic-deriving-1.12.1-FuroWhBR2UmCLOpOp0vyS5
key: generic-deriving-1.12.1-FuroWhBR2UmCLOpOp0vyS5
license: BSD-3-Clause
copyright: 2011-2013 Universiteit Utrecht, University of Oxford
maintainer: generics@haskell.org
author: José Pedro Magalhães
stability: experimental
homepage: https://github.com/dreixel/generic-deriving
synopsis: Generic programming library for generalised deriving.
description:
    This package provides functionality for generalising the deriving mechanism
    in Haskell to arbitrary classes. It was first described in the paper:
    .
    *  /A generic deriving mechanism for Haskell/.
    Jose Pedro Magalhaes, Atze Dijkstra, Johan Jeuring, and Andres Loeh.
    Haskell'\''10.
    .
    The current implementation integrates with the new GHC Generics. See
    <http://www.haskell.org/haskellwiki/GHC.Generics> for more information.
    Template Haskell code is provided for supporting older GHCs.
category: Generics
abi: d210dbf26eb75f0256eb795ece065ad8
exposed: True
exposed-modules:
    Generics.Deriving Generics.Deriving.Base Generics.Deriving.ConNames
    Generics.Deriving.Copoint Generics.Deriving.Enum
    Generics.Deriving.Eq Generics.Deriving.Foldable
    Generics.Deriving.Functor Generics.Deriving.Instances
    Generics.Deriving.Monoid Generics.Deriving.Semigroup
    Generics.Deriving.Show Generics.Deriving.TH
    Generics.Deriving.Traversable Generics.Deriving.Uniplate
hidden-modules: Generics.Deriving.Base.Internal
                Generics.Deriving.TH.Internal Paths_generic_deriving
                Generics.Deriving.TH.Post4_9
import-dirs: /usr/lib/ghc-8.4.3/site-local/generic-deriving-1.12.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/generic-deriving-1.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/generic-deriving-1.12.1
hs-libraries: HSgeneric-deriving-1.12.1-FuroWhBR2UmCLOpOp0vyS5
depends:
    containers-0.5.11.0 ghc-prim-0.5.2.0 template-haskell-2.13.0.0
    base-4.11.1.0
abi-depends: containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-generic-deriving/html/generic-deriving.haddock
haddock-html: /usr/share/doc/haskell-generic-deriving/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-deriving-1.12.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-generic-deriving.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-deriving
version: 1.12.1
id: generic-deriving-1.12.1-6ZQQXZqE8uYCSYf6aYj7NA
key: generic-deriving-1.12.1-6ZQQXZqE8uYCSYf6aYj7NA
license: BSD-3-Clause
copyright: 2011-2013 Universiteit Utrecht, University of Oxford
maintainer: generics@haskell.org
author: José Pedro Magalhães
stability: experimental
homepage: https://github.com/dreixel/generic-deriving
synopsis: Generic programming library for generalised deriving.
description:
    This package provides functionality for generalising the deriving mechanism
    in Haskell to arbitrary classes. It was first described in the paper:
    .
    *  /A generic deriving mechanism for Haskell/.
    Jose Pedro Magalhaes, Atze Dijkstra, Johan Jeuring, and Andres Loeh.
    Haskell'\''10.
    .
    The current implementation integrates with the new GHC Generics. See
    <http://www.haskell.org/haskellwiki/GHC.Generics> for more information.
    Template Haskell code is provided for supporting older GHCs.
category: Generics
abi: 223a32dd96b5b193cacd7602f3e20a54
exposed: True
exposed-modules:
    Generics.Deriving Generics.Deriving.Base Generics.Deriving.ConNames
    Generics.Deriving.Copoint Generics.Deriving.Enum
    Generics.Deriving.Eq Generics.Deriving.Foldable
    Generics.Deriving.Functor Generics.Deriving.Instances
    Generics.Deriving.Monoid Generics.Deriving.Semigroup
    Generics.Deriving.Show Generics.Deriving.TH
    Generics.Deriving.Traversable Generics.Deriving.Uniplate
hidden-modules: Generics.Deriving.Base.Internal
                Generics.Deriving.TH.Internal Paths_generic_deriving
                Generics.Deriving.TH.Post4_9
import-dirs: /usr/lib/ghc-8.4.3/site-local/generic-deriving-1.12.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/generic-deriving-1.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/generic-deriving-1.12.1
hs-libraries: HSgeneric-deriving-1.12.1-6ZQQXZqE8uYCSYf6aYj7NA
depends:
    containers-0.5.11.0 ghc-prim-0.5.2.0 template-haskell-2.13.0.0
    base-4.11.1.0
abi-depends: containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-generic-deriving/html/generic-deriving.haddock
haddock-html: /usr/share/doc/haskell-generic-deriving/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
